@@ -35,15 +35,15 @@ C ******************************************************************************
       subroutine fcrit(probs, cnorm, beta, wght, cval, size,
      &  precrt, nobs, model, nreg, np, nx)
 
-      implicit real*8 (a-h,o-z)
+      implicit real(8) (a-h,o-z)
 c
 c Copyright (c) James G. MacKinnon, 1995
 c Routine to find a critical value for any specified test size.
 c Uses GLS to estimate approximating regression.
 c
-      real*8 probs(221), cnorm(221), beta(4,221), crits(221), wght(221)
-      real*8 yvect(20),xmat(20,4),xomx(4,4),resid(20),gamma(4)
-      real*8 omega(20,20), fits(20)
+      real(8) probs(221), cnorm(221), beta(4,221), crits(221), wght(221)
+      real(8) yvect(20),xmat(20,4),xomx(4,4),resid(20),gamma(4)
+      real(8) omega(20,20), fits(20)
       diffm = 1000.d0
       imin = 0
       do i=1,221
@@ -193,14 +193,14 @@ C ******************************************************************************
 
       subroutine fpval(beta, cnorm, wght, probs, pval, stat,
      &  precrt, nobs, model, nreg, np, nx)
-      implicit real*8 (a-h,o-z)
+      implicit real(8) (a-h,o-z)
 c
 c Copyright (c) James G. MacKinnon, 1995
 c Routine to find P value for any specified test statistic.
 c
-      real*8 beta(4,221), crits(221), cnorm(221), wght(221), probs(221)
-      real*8 yvect(20),xmat(20,4),resid(20),gamma(4)
-      real*8 omega(20,20), fits(20), xomx(4,4)
+      real(8) beta(4,221), crits(221), cnorm(221), wght(221), probs(221)
+      real(8) yvect(20),xmat(20,4),resid(20),gamma(4)
+      real(8) omega(20,20), fits(20), xomx(4,4)
 c
 c first, compute all the estimated critical values
 c
@@ -356,13 +356,13 @@ C ******************************************************************************
 
 
       subroutine eval(beta,cval,model,nreg,nobs)
-      implicit real*8 (a-h,o-z)
+      implicit real(8) (a-h,o-z)
 
 c
 c Copyright (c) James G. MacKinnon, 1995
 c Routine to evaluate response surface for specified betas and sample size.
 c
-      real*8 beta(4)
+      real(8) beta(4)
       if (nobs.eq.0) then
          cval = beta(1)
          return
@@ -406,10 +406,10 @@ c Subroutine to do GLS estimation the obvious way
 c Use only when sample size is small (nobs <= 50)
 c 1995-1-3
 c
-      implicit real*8 (a-h,o-z)
-      real*8 xmat(nomax,nvmax), yvect(nomax), omega(nomax,nomax)
-      real*8 beta(nvmax), xomx(nvmax,nvmax), fits(nomax), resid(nomax)
-      real*8 xomy(50)
+      implicit real(8) (a-h,o-z)
+      real(8) xmat(nomax,nvmax), yvect(nomax), omega(nomax,nomax)
+      real(8) beta(nvmax), xomx(nvmax,nvmax), fits(nomax), resid(nomax)
+      real(8) xomy(50)
 c
 c xomx is covariance matrix of parameter estimates if omega is truly known
 c First, invert omega matrix if ivrt=0. Original one gets replaced.
@@ -481,13 +481,13 @@ C ******************************************************************************
 
 
       subroutine cholx(amat,m,n,kxx)
-      implicit real*8 (a-h,o-z)
+      implicit real(8) (a-h,o-z)
 c
 c     Copyright (c) James G. MacKinnon, 1993
 c     This routine uses the cholesky decomposition to invert a real
 c     symmetric matrix.
 c
-      real*8 amat(m,m)
+      real(8) amat(m,m)
       ooa = 1.d0 ! Wall
       kxx = 0
       do 8 i=1,n
@@ -539,7 +539,7 @@ C ******************************************************************************
 
 
       subroutine ddnor(ystar,gauss)
-      implicit real*8(a-h,o-z)
+      implicit real(8)(a-h,o-z)
 c
 c Copyright (c) James G. MacKinnon, 1993
 c Routine to evaluate cumulative normal distribution
@@ -551,7 +551,7 @@ c normal distribution. It is probably accurate to 19 or 20
 c significant digits. It was written in 1977, based on the Cody
 c article referred to in the documentation for IMSL subroutine mdnor.
 c
-      real*8 p(6), q(5), a(9), b(8), c(5), d(4)
+      real(8) p(6), q(5), a(9), b(8), c(5), d(4)
       data p(1)/-6.58749161529837803157d-04/,
      1     p(2)/-1.60837851487422766278d-02/,
      2     p(3)/-1.25781726111229246204d-01/,
@@ -667,7 +667,7 @@ C ******************************************************************************
 
 
       subroutine innorz(prob,anorm)
-      implicit real*8 (a-h,o-z)
+      implicit real(8) (a-h,o-z)
 c
 c Copyright (c) James G. MacKinnon, 1995
 c Inverse normal routine that adjusts crude result twice.
